@@ -2,6 +2,7 @@
 #'
 #' Caterpillar plots are plotted combining all chains for each parameter.
 #'
+#' @references Fernández-i-Marín, Xavier (2016) ggmcmc: Analysis of MCMC Samples and Bayesian Inference. Journal of Statistical Software, 70(9), 1-20. doi:10.18637/jss.v070.i09
 #' @param D Data frame whith the simulations or list of data frame with simulations. If a list of data frames with simulations is passed, the names of the models are the names of the objects in the list.
 #' @param X data frame with two columns, Parameter and the value for the x location. Parameter must be a character vector with the same names that the parameters in the D object. 
 #' @param family Name of the family of parameters to plot, as given by a character vector or a regular expression. A family of parameters is considered to be any group of parameters with the same name but different numerical value between square brackets (as beta[1], beta[2], etc). 
@@ -79,7 +80,7 @@ ggs_caterpillar <- function(D, family=NA, X=NA,
       geom_segment(aes(x=low, xend=high, yend=reorder(Parameter, median)), size=0.5) +
       xlab("HPD") + ylab("Parameter")
     if (greek) {
-      f <- f + scale_y_discrete(labels = parse(text = as.character(dcm$Parameter)))
+      f <- f + scale_y_discrete(labels = parse(text = as.character(dcm$Parameter[order(dcm$median)])))
     }
   } else {
     dcm <- merge(dcm, X)
